@@ -1,8 +1,8 @@
-def printlol(name,level):
+def printlol(name,level=0):
     for eachitem in name:
 	    if(isinstance(eachitem,list)):
 		    printlol(eachitem,level+1)
 	    else:
 		    for each_tab in range(level):
-			    print(eachitem)
+			    print("\t",end="")
 		    print(eachitem)
